#
Welcome to API Logic Server - Sample

## Automatic Admin App, Designed For

- Instant Agile Business User Collaboration
- Back Office Data Maintenance

## Key Features

- Multi-page: screen transitions
- Multi-table: child grids, parent joins
- Logic aware: multi-table derivations and constraints, extensible with Python events for email, messages, etc
- Customizable: see ui/admin/admin.yaml. Use SAFRS API for custom apps.

## Resources

- Tour
- Swagger
- API Logic Server Docs
- Admin App Customization Docs

## Sample Customizations

While the Sample Application is mainly created from the data model, it also includes these customizations you can explore:

- Customizing your admin app
- Customizing your api
- Customizing your logic